<?php

namespace Drupal\taxonomy_search\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;
use Drupal\taxonomy_search\TaxonomySearchManager;

/**
 * Edit search form for taxonomy term
 */
class EditForm extends FormBase {
    /**
     * Taxonomy Search Manager
     *
     * @var \Drupal\taxonomy_search\TaxonomySearchManager
     */
    protected $taxonomySearchManager;

    /**
     * Construct
     *
     * @param \Drupal\taxonomy_search\TaxonomySearchManager
     * @return void
     */
    public function __construct(TaxonomySearchManager $taxonmySearchManager) {
        $this->taxonomySearchManager = $taxonmySearchManager;
    }
 
    /**
     * create
     *
     * @param ContainerInterface $container
     */
    public static function create(ContainerInterface $container) {
        return new static(
            $container->get('taxonomy_search.manager'),
        );
    }

    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'taxonomy_search';
    }

    /**
     * Build taxonomy search form
     * 
     * @param array              $form
     * @param FormStateInterface $form_state
     *
     * @return array
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
        
        $vocabularies = $this->taxonomySearchManager->getVocabularies();
        $options = [];

        foreach ($vocabularies as $code => $vocabulary) {
            $options[$code] = $vocabulary->label();
        }
        
        $form['taxonomy_vocabulary'] = [
            '#type' => 'select',
            '#title' => $this->t('Vocabulary'),
            '#description' => $this->t('What vocabulary is involved?'),
            '#options' => $options,
            '#required' => true
        ];

        $form['taxonomy_term'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Term'),
            '#description' => $this->t('Which term to looking for from this vocabulary?'),
            '#required' => true
        ];

        $form['submit'] = [
            '#type' => 'submit',
            '#title' => $this->t('Search'),
            '#default_value' => "Search"
        ];

        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {

        $taxonomyVocabularyVid = $form_state->getValue('taxonomy_vocabulary');
        $termSearch = $form_state->getValue('taxonomy_term');
       
        $tid = $this->taxonomySearchManager->getSearch($taxonomyVocabularyVid, $termSearch);

        if (is_null($tid) || $tid === 0) {
            \Drupal::messenger()->addError($this->t('The term you are looking for from this vocabulary seems to not exist, please try again'));
            $response = Url::fromRoute('taxonomy_search.admin.search');
        } else {
            $response = Url::fromRoute('entity.taxonomy_term.edit_form', ['taxonomy_term' => $tid]);
        }

        $form_state->setRedirectUrl($response);
    } 
}
