<?php

namespace Drupal\taxonomy_search;

use Drupal\Core\Database\Connection;

/**
 * Taxonomy manager
 */
class TaxonomySearchManager implements TaxonomySearchInterface {
  /**
   * Database connection
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;
 
  /**
   * Vocabularies
   *
   * @var array
   */
  protected $vocabularies = [];

  /**
   * @var Drupal\Core\Database\Connection
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }
  
  /**
   * Get search
   * 
   * @param string $taxonomyVocabularyVid taxonomy Vocabulary Vid
   * @param string $termSearch            term search
   *
   * @return int
   */
  public function getSearch($taxonomyVocabularyVid, $termSearch) {
    $query = $this->connection->select('taxonomy_term_field_data', 'ttfd');
    $query->innerJoin('taxonomy_term_data', 'ttd', 'ttfd.tid = ttd.tid');
    $query->condition('ttd.vid', $taxonomyVocabularyVid);
    $query->condition('ttfd.name', "%" . $this->connection->escapeLike($termSearch) . "%", 'LIKE');
    $query->fields('ttfd', ['tid']);
    return (int) $query->execute()
    ->fetchField();
  }
  
  /**
   * Get Vocabularies
   * 
   * @return array || null 
   */
  public function getVocabularies() {
    if (empty($this->vocabularies)) {
        $this->vocabularies = \Drupal\taxonomy\Entity\Vocabulary::loadMultiple();
    }
    return $this->vocabularies;
  }
}
